class Parameter < ActiveRecord::Base
  extend FriendlyId
  friendly_id :name
  include Parameterizable::ByIdName
  include HiddenValue

  attr_accessible :name, :value, :hidden_value, :_destroy, :id, :nested, :reference_id

  validates_lengths_from_database

  include Authorizable
  validates :name, :presence => true, :no_whitespace => true

  scoped_search :on => :name, :complete_value => true

  default_scope -> { order("parameters.name") }

  before_create :set_priority

  PRIORITY = { :common_parameter => 0,
               :organization_parameter => 10,
               :location_parameter => 20,
               :domain_parameter => 30,
               :subnet_parameter => 40,
               :os_parameter => 50,
               :group_parameter => 60,
               :host_parameter => 70
             }

  def self.type_priority(type)
    PRIORITY.fetch(type.to_s.underscore.to_sym, nil) unless type.nil?
  end

  private

  def set_priority
    self.priority = Parameter.type_priority(type)
  end

  def skip_strip_attrs
    ['value']
  end

  # hack fix for Rails 3.2.8. Not needed for 3.2.18.
  # related to **accepts_nested_attributes_for** on UI form (not API)
  # which incorrectly assigns foreign key to 1 when attributes are from STI class (DomainParamter, HostParameter, etc)
  def ensure_reference_nil
    self.reference_id = nil if self.new_record? && self.reference_id == 1 && Rails.version == '3.2.8'
  end
end
